from data_scraper import *
def run_imgur_wesbite_scraper(link):
    Id="JWTSHCU5NLSPXXK"
    response=scraper.run(link,id=Id)
    return response